@@ -16,16 +16,17 @@
 
 import asyncio
 import copy
-from typing import Optional, List, Any, Mapping, Union, Callable, TYPE_CHECKING, cast
+from typing import Optional, List, Any, Mapping, Union, Set, Callable, Tuple, TYPE_CHECKING, cast
 from . import _types
 from .metadata import get_project, get_stack
 from .runtime import known_types
 from .runtime.resource import get_resource, register_resource, register_resource_outputs, read_resource, \
     convert_providers
 from .runtime.settings import get_root_resource
+from .output import _is_prompt, _map_input, _map2_input, T, Output
 
 if TYPE_CHECKING:
-    from .output import Input, Inputs, Output
+    from .output import Input, Inputs
     from .runtime.stack import Stack
 
 
@@ -78,7 +79,6 @@ def inherited_child_alias(
 #   * parentAliasName: "app"
 #   * aliasName: "app-function"
 #   * childAlias: "urn:pulumi:stackname::projectname::aws:s3/bucket:Bucket::app-function"
-    from . import Output  # pylint: disable=import-outside-toplevel
     alias_name = Output.from_input(child_name)
     if child_name.startswith(parent_name):
         alias_name = Output.from_input(parent_alias).apply(
@@ -185,7 +185,6 @@ def collapse_alias_to_urn(
     """
     collapse_alias_to_urn turns an Alias into a URN given a set of default data
     """
-    from . import Output  # pylint: disable=import-outside-toplevel
 
     def collapse_alias_to_urn_worker(inner: Union[Alias, str]) -> Output[str]:
         if isinstance(inner, str):
@@ -298,9 +297,9 @@ class ResourceOptions:
     resource.
     """
 
-    depends_on: Optional[List['Resource']]
+    depends_on: Optional['Input[Union[List[Input[Resource]], Resource]]']
     """
-    If provided, the currently-constructing resource depends on the provided list of resources.
+    If provided, declares that the currently-constructing resource depends on the given resources.
     """
 
     protect: Optional[bool]
@@ -391,7 +390,7 @@ class ResourceOptions:
     # pylint: disable=redefined-builtin
     def __init__(self,
                  parent: Optional['Resource'] = None,
-                 depends_on: Optional[List['Resource']] = None,
+                 depends_on: Optional['Input[Union[List[Input[Resource]], Resource]]'] = None,
                  protect: Optional[bool] = None,
                  provider: Optional['ProviderResource'] = None,
                  providers: Optional[Union[Mapping[str, 'ProviderResource'], List['ProviderResource']]] = None,
@@ -409,8 +408,8 @@ class ResourceOptions:
         """
         :param Optional[Resource] parent: If provided, the currently-constructing resource should be the child of
                the provided parent resource.
-        :param Optional[List[Resource]] depends_on: If provided, the currently-constructing resource depends on the
-               provided list of resources.
+        :param Optional[Input[Union[List[Input[Resource]],Resource]]] depends_on: If provided, declares that the
+               currently-constructing resource depends on the given resources.
         :param Optional[bool] protect: If provided and True, this resource is not allowed to be deleted.
         :param Optional[ProviderResource] provider: An optional provider to use for this resource's CRUD operations.
                If no provider is supplied, the default provider for the resource's package will be used. The default
@@ -449,7 +448,6 @@ class ResourceOptions:
         self.merge.__func__.__doc__ = ResourceOptions.merge.__doc__ # type: ignore
 
         self.parent = parent
-        self.depends_on = depends_on
         self.protect = protect
         self.provider = provider
         self.providers = providers
@@ -464,16 +462,27 @@ class ResourceOptions:
         self.transformations = transformations
         self.urn = urn
         self.replace_on_changes = replace_on_changes
+        self.depends_on = depends_on
 
-        if depends_on is not None:
-            for dep in depends_on:
-                if not isinstance(dep, Resource):
-                    raise Exception(
-                        "'depends_on' was passed a value that was not a Resource.")
+        # Proactively check that `depends_on` values are of type
+        # `Resource`. We cannot complete the check in the general case
+        # and can only do it on promptly available arguments.
+        deps = self._depends_on_list()
+        if isinstance(deps, list):
+            for dep in deps:
+                if _is_prompt(dep) and not isinstance(dep, Resource):
+                    raise Exception(f"'depends_on' was passed a value {dep} that was not a Resource.")
 
     def _merge_instance(self, opts: 'ResourceOptions') -> 'ResourceOptions':
         return ResourceOptions.merge(self, opts)
 
+    def _depends_on_list(self) -> 'Input[List[Input[Resource]]]':
+
+        if self.depends_on is None:
+            return []
+
+        return _map_input(self.depends_on, lambda x: x if isinstance(x, list) else [cast(Any, x)])
+
     # pylint: disable=method-hidden
     @staticmethod
     def merge(opts1: Optional['ResourceOptions'], opts2: Optional['ResourceOptions']) -> 'ResourceOptions':
@@ -521,7 +530,11 @@ class ResourceOptions:
         _expand_providers(source)
 
         dest.providers = _merge_lists(dest.providers, source.providers)
-        dest.depends_on = _merge_lists(dest.depends_on, source.depends_on)
+
+        dest.depends_on = _map2_input(dest._depends_on_list(),
+                                      source._depends_on_list(),
+                                      lambda xs, ys: xs + ys)
+
         dest.ignore_changes = _merge_lists(dest.ignore_changes, source.ignore_changes)
         dest.replace_on_changes = _merge_lists(dest.replace_on_changes, source.replace_on_changes)
         dest.aliases = _merge_lists(dest.aliases, source.aliases)
@@ -945,8 +958,6 @@ class DependencyResource(CustomResource):
     def __init__(self, urn: str) -> None:
         super().__init__(t="", name="", props={}, opts=None, dependency=True)
 
-        from . import Output  # pylint: disable=import-outside-toplevel
-
         urn_future: asyncio.Future[str] = asyncio.Future()
         urn_known: asyncio.Future[bool] = asyncio.Future()
         urn_secret: asyncio.Future[bool] = asyncio.Future()
@@ -963,14 +974,15 @@ class DependencyProviderResource(ProviderResource):
     """
 
     def __init__(self, ref: str) -> None:
-        super().__init__(pkg="", name="", props={}, opts=None, dependency=True)
+        ref_urn, ref_id = _parse_resource_reference(ref)
+        urn_parts = ref_urn.split("::")
+        qualified_type = urn_parts[2]
+        typ = qualified_type.split("$")[-1]
+        typ_parts = typ.split(":")
+        # typ will be "pulumi:providers:<package>" and we want the last part.
+        pkg = typ_parts[2] if len(typ_parts) > 2 else ""
 
-        # Parse the URN and ID out of the provider reference.
-        last_sep = ref.rindex("::")
-        ref_urn = ref[:last_sep]
-        ref_id = ref[last_sep+2:]
-
-        from . import Output  # pylint: disable=import-outside-toplevel
+        super().__init__(pkg=pkg, name="", props={}, opts=None, dependency=True)
 
         urn_future: asyncio.Future[str] = asyncio.Future()
         urn_known: asyncio.Future[bool] = asyncio.Future()
@@ -1013,7 +1025,6 @@ def create_urn(
     create_urn computes a URN from the combination of a resource name, resource type, optional
     parent, optional project and optional stack.
     """
-    from . import Output  # pylint: disable=import-outside-toplevel
     parent_prefix: Optional[Output[str]] = None
     if parent is not None:
         parent_urn = None
@@ -1036,3 +1047,13 @@ def create_urn(
     all_args = [parent_prefix, type_, name]
     # invariant http://mypy.readthedocs.io/en/latest/common_issues.html#variance
     return Output.all(*all_args).apply(lambda arr: arr[0] + arr[1] + "::" + arr[2]) # type: ignore
+
+
+def _parse_resource_reference(ref: str) -> Tuple[str, str]:
+    """
+    Parses the URN and ID out of the provider reference.
+    """
+    last_sep = ref.rindex("::")
+    ref_urn = ref[:last_sep]
+    ref_id = ref[last_sep+2:]
+    return (ref_urn, ref_id)
