@@ -21,9 +21,14 @@ func main() {
 	if _, ok := os.LookupEnv("INCLUDE_SCHEMA"); ok {
 		schema = `{"hello": "world"}`
 	}
-	err := provider.ComponentMain(providerName, version, []byte(schema), func(ctx *pulumi.Context, typ, name string,
-		inputs pulumiprovider.ConstructInputs, options pulumi.ResourceOption) (*pulumiprovider.ConstructResult, error) {
-		return nil, errors.Errorf("unknown resource type %s", typ)
+	err := provider.MainWithOptions(provider.Options{
+		Name:    providerName,
+		Version: version,
+		Schema:  []byte(schema),
+		Construct: func(ctx *pulumi.Context, typ, name string,
+			inputs pulumiprovider.ConstructInputs, options pulumi.ResourceOption) (*pulumiprovider.ConstructResult, error) {
+			return nil, errors.Errorf("unknown resource type %s", typ)
+		},
 	})
 	if err != nil {
 		cmdutil.ExitError(err.Error())
