@@ -733,6 +733,10 @@ func TestConstructMethodsPython(t *testing.T) {
 	}
 }
 
+func TestConstructMethodsUnknownPython(t *testing.T) {
+	testConstructMethodsUnknown(t, "python", filepath.Join("..", "..", "sdk", "python", "env", "src"))
+}
+
 func TestConstructProviderPython(t *testing.T) {
 	const testDir = "construct_component_provider"
 	tests := []struct {
